pub fn encode_frame(command: EscCommand) -> u32Expand description
Encodes a throttle command and telemetry request into a DSHOT frame
pub fn encode_frame(command: EscCommand) -> u32Encodes a throttle command and telemetry request into a DSHOT frame